@@ -10,7 +10,8 @@ assignment_linter <- function(source_file) {
         column_number = parsed$col1,
         type = "style",
         message = "Use <-, not =, for assignment.",
-        line = source_file$lines[as.character(parsed$line1)]
+        line = source_file$lines[as.character(parsed$line1)],
+        linter = "assignment_linter"
         )
     })
 }
