@@ -1,30 +1,30 @@
-context("object_camel_case_linter")
+context("camel_case_linter")
 test_that("returns the correct linting", {
   expect_lint("blah",
     NULL,
-    object_camel_case_linter)
+    camel_case_linter)
 
   expect_lint("invokeRestartInteractively",
     NULL,
-    object_camel_case_linter)
+    camel_case_linter)
 
   expect_lint("camelCase",
     rex("Variable and function names should be all lowercase."),
-    object_camel_case_linter)
+    camel_case_linter)
 
   expect_lint("camelCase()",
     rex("Variable and function names should be all lowercase."),
-    object_camel_case_linter)
+    camel_case_linter)
 
   expect_lint("pack::camelCase",
     NULL,
-    object_camel_case_linter)
+    camel_case_linter)
 
   expect_lint("pack:::camelCase",
     NULL,
-    object_camel_case_linter)
+    camel_case_linter)
 
   expect_lint("a(camelCase = 1)",
     NULL,
-    object_camel_case_linter)
+    camel_case_linter)
 })
